@@ -3,6 +3,8 @@ import json
 import gzip
 import logging
 
+from itertools import islice, chain
+
 from enum import Enum
 
 from io import TextIOWrapper
@@ -38,14 +40,28 @@ logstash_logger = logging.getLogger('security.logstash')
 MAX_VERSION = 9999
 
 
-def lazy_serialize_qs(qs):
-    def generator():
-        for obj in qs:
+def batch(iterable, size):
+    sourceiter = iter(iterable)
+    try:
+        while True:
+            batchiter = islice(sourceiter, size)
+            yield chain([next(batchiter)], batchiter)
+    except StopIteration:
+        pass
+
+
+def get_queryset_dict_data_by_batch(qs, batch_size):
+    for batch_qs in get_querysets_by_batch(qs, batch_size):
+        for obj in batch_qs:
             yield obj.to_dict()
 
+
+def lazy_serialize_iterable(iterable):
+
     class StreamList(list):
         def __iter__(self):
-            return generator()
+            for obj in iterable:
+                yield obj
 
         def __len__(self):
             return 1
@@ -387,7 +403,7 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
 
         qs = get_log_model_from_logger_name(type).search().filter(
             Q('range', stop={'lt': timestamp})
-        ).sort('stop', '_id')
+        ).sort('stop')
         step_timestamp = None
         if qs.count() != 0:
             step_timestamp = list(qs[0:1])[0].stop
@@ -396,7 +412,9 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
             min_timestamp = datetime.combine(step_timestamp, time.min).replace(tzinfo=utc)
             max_timestamp = datetime.combine(step_timestamp, time.max).replace(tzinfo=utc)
 
-            qs_filtered_by_day = qs.filter(Q('range', stop={'gte': min_timestamp, 'lte': max_timestamp}))
+            qs_filtered_by_day = qs.filter(Q('range', stop={'gte': min_timestamp, 'lte': max_timestamp})).sort(
+                'stop', '_id'
+            )
 
             if qs_filtered_by_day.count() != 0:
                 stdout.write(
@@ -406,7 +424,9 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
                 )
 
                 if backup_path:
-                    for qs_batch in get_querysets_by_batch(qs_filtered_by_day, settings.PURGE_LOG_BACKUP_BATCH):
+                    for batch_data in batch(get_queryset_dict_data_by_batch(qs_filtered_by_day,
+                                                                            settings.ELASTICSERACH_BACKUP_BATCH_SIZE),
+                                            settings.PURGE_LOG_BACKUP_BATCH):
                         log_file_name = os.path.join(backup_path, str(step_timestamp.date()))
                         if storage.exists('{}.json.gz'.format(log_file_name)):
                             i = 1
@@ -418,7 +438,7 @@ class ElasticsearchBackendWriter(BaseBackendWriter):
                             with TextIOWrapper(gzip.GzipFile(filename='{}.json'.format(log_file_name),
                                                              fileobj=f, mode='wb')) as gzf:
                                 json.dump(
-                                    lazy_serialize_qs(qs_batch), gzf, cls=DjangoJSONEncoder, indent=5
+                                    lazy_serialize_iterable(batch_data), gzf, cls=DjangoJSONEncoder, indent=5
                                 )
                 stdout.write(4 * ' ' + 'deleting logs')
                 qs_filtered_by_day.delete()
